diff --git a/browse_foreigners.php b/browse_foreigners.php
index 490a06cdee..27781a4a78 100644
--- a/browse_foreigners.php
+++ b/browse_foreigners.php
@@ -88,7 +88,7 @@ $current_language = $available_languages[$lang][1];
phpMyAdmin
+ href="phpmyadmin.css.php?&nocache=getThemeUniqueValue(); ?>" />
' . "\n";
foreach ($this->getGroupedDetails($offset, $count) as $group => $dbs) {
if (count($dbs) > 1) {
- $return .= '' . htmlspecialchars($group)
+ $return .= '' . htmlspecialchars($group)
. '' . "\n";
// whether display db_name cut by the group part
$cut = true;
diff --git a/libraries/Theme_Manager.class.php b/libraries/Theme_Manager.class.php
index 440374d8fa..d9a6f5c580 100644
--- a/libraries/Theme_Manager.class.php
+++ b/libraries/Theme_Manager.class.php
@@ -48,7 +48,12 @@ class PMA_Theme_Manager
/**
* @var string
*/
- var $theme_default = 'original';
+ var $theme_default;
+
+ /**
+ * @const string The name of the fallback theme
+ */
+ const FALLBACK_THEME = 'pmahomme';
function __construct()
{
@@ -94,7 +99,7 @@ class PMA_Theme_Manager
function init()
{
$this->themes = array();
- $this->theme_default = 'original';
+ $this->theme_default = self::FALLBACK_THEME;
$this->active_theme = '';
if (! $this->setThemesPath($GLOBALS['cfg']['ThemePath'])) {
@@ -125,12 +130,12 @@ class PMA_Theme_Manager
if (! $this->getThemeCookie()
|| ! $this->setActiveTheme($this->getThemeCookie())
) {
- // otherwise use default theme
if ($GLOBALS['cfg']['ThemeDefault']) {
- $this->setActiveTheme($GLOBALS['cfg']['ThemeDefault']);
+ // otherwise use default theme
+ $this->setActiveTheme($this->theme_default);
} else {
- // or original theme
- $this->setActiveTheme('original');
+ // or fallback theme
+ $this->setActiveTheme(self::FALLBACK_THEME);
}
}
}
@@ -365,8 +370,8 @@ class PMA_Theme_Manager
*/
function getFallBackTheme()
{
- if (isset($this->themes['original'])) {
- return $this->themes['original'];
+ if (isset($this->themes[self::FALLBACK_THEME])) {
+ return $this->themes[self::FALLBACK_THEME];
}
return false;
@@ -375,19 +380,17 @@ class PMA_Theme_Manager
/**
* prints css data
*
- * @param string $type
- *
* @return bool
*/
- function printCss($type)
+ function printCss()
{
- if ($this->theme->loadCss($type)) {
+ if ($this->theme->loadCss()) {
return true;
}
// if loading css for this theme failed, try default theme css
$fallback_theme = $this->getFallBackTheme();
- if ($fallback_theme && $fallback_theme->loadCss($type)) {
+ if ($fallback_theme && $fallback_theme->loadCss()) {
return true;
}
diff --git a/libraries/common.inc.php b/libraries/common.inc.php
index 0c0392559e..f3b0b183bc 100644
--- a/libraries/common.inc.php
+++ b/libraries/common.inc.php
@@ -554,12 +554,6 @@ if (PMA_isValid($_REQUEST['sql_query'])) {
$GLOBALS['sql_query'] = $_REQUEST['sql_query'];
}
-/**
- * avoid problems in phpmyadmin.css.php in some cases
- * @global string $js_frame
- */
-$_REQUEST['js_frame'] = PMA_ifSetOr($_REQUEST['js_frame'], '');
-
//$_REQUEST['set_theme'] // checked later in this file LABEL_theme_setup
//$_REQUEST['server']; // checked later in this file
//$_REQUEST['lang']; // checked by LABEL_loading_language_file
diff --git a/libraries/header_meta_style.inc.php b/libraries/header_meta_style.inc.php
index 63cb8d15e8..66c5b75deb 100644
--- a/libraries/header_meta_style.inc.php
+++ b/libraries/header_meta_style.inc.php
@@ -44,7 +44,7 @@ if ($GLOBALS['text_dir'] == 'ltr') {
echo 'phpMyAdmin';
}
?>
-
+
diff --git a/libraries/mult_submits.inc.php b/libraries/mult_submits.inc.php
index 851dee0799..476e5c4f20 100644
--- a/libraries/mult_submits.inc.php
+++ b/libraries/mult_submits.inc.php
@@ -11,7 +11,6 @@ if (! defined('PHPMYADMIN')) {
$request_params = array(
'clause_is_unique',
'goto',
- 'js_frame',
'mult_btn',
'original_sql_query',
'query_type',
diff --git a/navigation.php b/navigation.php
index 7694ae5d2a..a341fd89b9 100644
--- a/navigation.php
+++ b/navigation.php
@@ -98,7 +98,7 @@ require_once 'libraries/header_http.inc.php';
+ href="phpmyadmin.css.php?&nocache=getThemeUniqueValue(); ?>" />
printCss(PMA_FRAME);
+$_SESSION['PMA_Theme_Manager']->printCss();
?>
diff --git a/test/theme.php b/test/theme.php
index 56e0630779..d6aa6f7851 100644
--- a/test/theme.php
+++ b/test/theme.php
@@ -25,10 +25,10 @@ header('Content-Type: text/html; charset=utf-8');
phpMyAdmin -
- - Theme Test
+ - Theme Test
+ href="../phpmyadmin.css.php?&nocache=getThemeUniqueValue(); ?>" />
diff --git a/themes/original/css/theme_right.css.php b/themes/original/css/common.css.php
similarity index 78%
rename from themes/original/css/theme_right.css.php
rename to themes/original/css/common.css.php
index c47859e710..846025f444 100644
--- a/themes/original/css/theme_right.css.php
+++ b/themes/original/css/common.css.php
@@ -1,14 +1,14 @@
@@ -1659,44 +1659,6 @@ input#input_import_file {
margin: 5px 0 5px 0;
}
-/**
- * GIS data editor styles
- */
-a.close_gis_editor {
- float: right;
-}
-
-#gis_editor {
- display: none;
- position: fixed;
- _position: absolute; /* hack for IE */
- z-index: 1001;
- overflow-y: auto;
- overflow-x: hidden;
-}
-
-#gis_data {
- min-height: 230px;
-}
-
-#gis_data_textarea {
- height: 6em;
-}
-
-#gis_data_editor {
- background: #D0DCE0;
- padding: 15px;
- min-height: 500px;
-}
-
-#gis_data_editor .choice {
- display: none;
-}
-
-#gis_data_editor input[type="text"] {
- width: 75px;
-}
-
#popup_background {
display: none;
position: fixed;
@@ -1710,86 +1672,6 @@ a.close_gis_editor {
overflow: hidden;
}
-/**
- * ENUM/SET editor styles
- */
-p.enum_notice {
- margin: 5px 2px;
- font-size: 80%;
-}
-
-fieldset.enum_editor_no_js {
- width: 40em;
- padding: 1em;
-}
-
-hr.enum_editor_no_js {
- background-color: #aaa;
-}
-
-#enum_editor p {
- font-style:italic;
-}
-
-#enum_editor .values, #enum_editor .add, .enum_editor_no_js #values {
- width: 100%;
-}
-
-#enum_editor .add td {
- vertical-align: middle;
- width: 50%;
- padding: 0 1em;
-}
-
-#enum_editor .values td.drop {
- width: 2em;
- cursor: pointer;
- vertical-align: middle;
-}
-
-#enum_editor .values input {
- margin: 0.1em 0;
- padding-right: 2.5em;
- width: 100%;
-}
-
-#enum_editor .values img {
- width: 2em;
- vertical-align: middle;
-}
-
-#enum_editor input.add_value {
- margin: 1em 0;
-}
-
-#enum_editor_output textarea,
-.enum_editor_no_js input {
- width: 100%;
- float: right;
- margin: 1em 0 0 0;
-}
-
-#enum_editor_no_js {
- width: 100%;
-}
-
-.enum_editor_no_js input.submit {
- margin: 1em 0;
-}
-
-/**
- * ENUM/SET editor integration for the routines editor
- */
-.enum_hint {
- position: relative;
-}
-
-.enum_hint a {
- position: absolute;
- left: 81%;
- bottom: 0.35em;
-}
-
/**
* Create table styles
*/
@@ -2109,34 +1991,6 @@ fieldset .disabled-field td {
margin-bottom: .5em;
}
-.rte_table {
- table-layout: fixed;
-}
-
-.rte_table td {
- vertical-align: middle;
- padding: 0.2em;
-}
-
-.rte_table tr td:nth-child(1) {
- font-weight: bold;
-}
-
-.rte_table input,
-.rte_table select,
-.rte_table textarea {
- width: 100%;
- margin: 0;
- box-sizing: border-box;
- -ms-box-sizing: border-box;
- -moz-box-sizing: border-box;
- -webkit-box-sizing: border-box;
-}
-
-.rte_table .routine_params_table {
- width: 100%;
-}
-
#placeholder .button {
position: absolute;
cursor: pointer;
@@ -2258,28 +2112,6 @@ fieldset .disabled-field td {
top: 103px;
}
-.gis_table td {
- vertical-align: middle;
-}
-
-.gis_table select {
- min-width: 151px;
-}
-
-.gis_table .save {
- font-weight: bold;
- vertical-align: bottom;
- height: 100px;
-}
-
-.gis_table .button {
- text-align: ;
-}
-
-.gis_table .choice {
- display: none;
-}
-
getCssCodeMirror(true); ?>
.colborder {
@@ -2535,515 +2367,6 @@ fieldset .disabled-field td {
.ui-timepicker-div dl dd { margin: -25px 0 10px 65px; }
.ui-timepicker-div td { font-size: 90%; }
-/* Designer */
-.input_tab {
- background-color: #A6C7E1;
- color: #000;
-}
-
-#canvas {
- background-color: #fff;
- color: #000;
-}
-
-canvas.pmd {
- display: inline-block;
- overflow: hidden;
- text-align: left;
-}
-
-canvas.pmd * {
- behavior: url(#default#VML);
-}
-
-.pmd_tab {
- background-color: #fff;
- color: #000;
- border-collapse: collapse;
- border: 1px solid #aaa;
- z-index: 1;
- -moz-user-select: none;
-}
-
-.tab_zag {
- background-image: url(getImgPath(); ?>pmd/Header.png);
- background-repeat: repeat-x;
- text-align: center;
- cursor: move;
- padding: 1px;
- font-weight: bold;
-}
-
-.tab_zag_2 {
- background-image: url(getImgPath(); ?>pmd/Header_Linked.png);
- background-repeat: repeat-x;
- text-align: center;
- cursor: move;
- padding: 1px;
- font-weight: bold;
-}
-
-.tab_field {
- background: #fff;
- color: #000;
- cursor: default;
-}
-
-.tab_field_2 {
- background-color: #CCFFCC;
- color: #000;
- background-repeat: repeat-x;
- cursor: default;
-}
-
-.tab_field_3 {
- background-color: #FFE6E6; /*#DDEEFF*/
- color: #000;
- cursor: default;
-}
-
-#pmd_hint {
- white-space: nowrap;
- position: absolute;
- background-color: #99FF99;
- color: #000;
- left: 200px;
- top: 50px;
- z-index: 3;
- border: #00CC66 solid 1px;
- display: none;
-}
-
-.scroll_tab {
- overflow: auto;
- width: 100%;
- height: 500px;
-}
-
-.pmd_Tabs {
- cursor: default;
- color: #0055bb;
- white-space: nowrap;
- text-decoration: none;
- text-indent: 3px;
- font-weight: bold;
- margin-left: 2px;
- text-align: left;
- background-color: #fff;
- background-image: url(getImgPath(); ?>pmd/left_panel_butt.png);
- border: #ccc solid 1px;
-}
-
-.pmd_Tabs2 {
- cursor: default;
- color: #0055bb;
- background: #FFEE99;
- text-indent: 3px;
- font-weight: bold;
- white-space: nowrap;
- text-decoration: none;
- border: #9999FF solid 1px;
- text-align: left;
-}
-
-.owner {
- font-weight: normal;
- color: #888;
-}
-
-.option_tab {
- padding-left: 2px;
- padding-right: 2px;
- width: 5px;
-}
-
-.select_all {
- vertical-align: top;
- padding-left: 2px;
- padding-right: 2px;
- cursor: default;
- width: 1px;
- color: #000;
- background-image: url(getImgPath(); ?>pmd/Header.png);
- background-repeat: repeat-x;
-}
-
-.small_tab {
- vertical-align: top;
- background-color: #0064ea;
- color: #fff;
- background-image: url(getImgPath(); ?>pmd/small_tab.png);
- cursor: default;
- text-align: center;
- font-weight: bold;
- padding-left: 2px;
- padding-right: 2px;
- width: 1px;
- text-decoration: none;
-}
-
-.small_tab2 {
- vertical-align: top;
- color: #fff;
- background-color: #FF9966;
- cursor: default;
- padding-left: 2px;
- padding-right: 2px;
- text-align: center;
- font-weight: bold;
- width: 1px;
- text-decoration: none;
-}
-
-.small_tab_pref {
- background-image: url(getImgPath(); ?>pmd/Header.png);
- background-repeat: repeat-x;
- text-align: center;
- width: 1px;
-}
-
-.small_tab_pref2 {
- vertical-align: top;
- color: #fff;
- background-color: #FF9966;
- cursor: default;
- text-align: center;
- font-weight: bold;
- width: 1px;
- text-decoration: none;
-}
-
-.butt {
- border: #4477aa solid 1px;
- font-weight: bold;
- height: 19px;
- width: 70px;
- background-color: #fff;
- color: #000;
- vertical-align: baseline;
-}
-
-.L_butt2_1 {
- padding: 1px;
- text-decoration: none;
- background-color: #fff;
- color: #000;
- vertical-align: middle;
- cursor: default;
-}
-
-.L_butt2_2 {
- padding: 0;
- border: #0099CC solid 1px;
- background: #FFEE99;
- text-decoration: none;
- color: #000;
- cursor: default;
-}
-
-/* ---------------------------------------------------------------------------*/
-.bor {
- width: 10px;
- height: 10px;
-}
-
-.frams1 {
- background: url(getImgPath(); ?>pmd/1.png) no-repeat right bottom;
-}
-
-.frams2 {
- background: url(getImgPath(); ?>pmd/2.png) no-repeat left bottom;
-}
-
-.frams3 {
- background: url(getImgPath(); ?>pmd/3.png) no-repeat left top;
-}
-
-.frams4 {
- background: url(getImgPath(); ?>pmd/4.png) no-repeat right top;
-}
-
-.frams5 {
- background: url(getImgPath(); ?>pmd/5.png) repeat-x center bottom;
-}
-
-.frams6 {
- background: url(getImgPath(); ?>pmd/6.png) repeat-y left;
-}
-
-.frams7 {
- background: url(getImgPath(); ?>pmd/7.png) repeat-x top;
-}
-
-.frams8 {
- background: url(getImgPath(); ?>pmd/8.png) repeat-y right;
-}
-
-#osn_tab {
- background-color: #fff;
- color: #000;
- border: #A9A9A9 solid 1px;
-}
-
-.pmd_header {
- background-color: #EAEEF0;
- color: #000;
- text-align: center;
- font-weight: bold;
- margin: 0;
- padding: 0;
- background-image: url(getImgPath(); ?>pmd/top_panel.png);
- background-position: top;
- background-repeat: repeat-x;
- border-right: #999 solid 1px;
- border-left: #999 solid 1px;
- height: 28px;
-}
-
-.pmd_header a {
- display: block;
- float: left;
- margin: 3px 1px 4px 1px;
- height: 20px;
- border: 1px dotted #fff;
-}
-
-.pmd_header .M_bord {
- display: block;
- float: left;
- margin: 4px;
- height: 20px;
- width: 2px;
-}
-
-.pmd_header a.first {
- margin-right: 1em;
-}
-
-.pmd_header a.last {
- margin-left: 1em;
-}
-
-a.M_butt_Selected_down_IE,
-a.M_butt_Selected_down {
- border: 1px solid #C0C0BB;
- background-color: #99FF99;
- color: #000;
-}
-
-a.M_butt_Selected_down_IE:hover,
-a.M_butt_Selected_down:hover,
-a.M_butt:hover {
- border: 1px solid #0099CC;
- background-color: #FFEE99;
- color: #000;
-}
-
-#layer_menu {
- z-index: 1000;
- position: absolute;
- left: 0;
- background-color: #EAEEF0;
- border: #999 solid 1px;
-}
-
-#layer_upd_relation {
- position: absolute;
- left: 637px;
- top: 224px;
- z-index: 1000;
-}
-
-#layer_new_relation {
- position: absolute;
- left: 636px;
- top: 85px;
- z-index: 1000;
- width: 153px;
-}
-
-#pmd_optionse {
- position: absolute;
- left: 636px;
- top: 85px;
- z-index: 1000;
- width: 153px;
-}
-
-#layer_menu_sizer {
- background-image: url(getImgPath(); ?>pmd/resize.png);
- cursor: nw-resize;
- width: 16px;
- height: 16px;
-}
-
-.panel {
- position: fixed;
- top: 50px;
- right: 0;
- display: none;
- background: #FFF;
- border: 1px solid #F5F5F5;
- width: 350 px;
- height: auto;
- padding: 30px 170px 30px 30px;
- color: #FFF;
- z-index: 99;
-}
-
-a.trigger {
- position: fixed;
- text-decoration: none;
- top: 60px; right: 0;
- color: #fff;
- padding: 10px 40px 10px 15px;
- background: #333 url(getImgPath(); ?>pmd/plus.png) 85% 55% no-repeat;
- border: 1px solid #444;
- display: block;
-}
-
-a.trigger:hover {
- position: fixed;
- text-decoration: none;
- top: 60px; right: 0;
- color: #080808;
- padding: 10px 40px 10px 15px;
- background: #fff696 url(getImgPath(); ?>pmd/plus.png) 85% 55% no-repeat;
- border: 1px solid #999;
- display: block;
-}
-
-a.active.trigger {
- background: #222 url(getImgPath(); ?>pmd/minus.png) 85% 55% no-repeat;
- z-index: 999;
-}
-
-a.active.trigger:hover {
- background: #fff696 url(getImgPath(); ?>pmd/minus.png) 85% 55% no-repeat;
- z-index: 999;
-}
-
-h2.tiger {
- background-repeat: repeat-x;
- padding: 1px;
- font-weight: bold;
- padding: 50 20 50 20px;
- margin: 0 0 5px 0;
- width: 250px;
- float: left;
- color : #333;
- text-align: center;
-}
-
-h2.tiger a {
- background-image: url(getImgPath(); ?>pmd/Header.png);
- text-align: center;
- text-decoration: none;
- color : #333;
- display: block;
-}
-
-h2.tiger a:hover {
- color: #000;
- background-image: url(getImgPath(); ?>pmd/Header_Linked.png);
-}
-
-h2.active {
- background-image: url(getImgPath(); ?>pmd/Header.png);
- background-repeat: repeat-x;
- padding: 1px;
- background-position: left bottom;
-}
-
-.toggle_container {
- margin: 0 0 5px;
- padding: 0;
- border-top: 1px solid #d6d6d6;
- background: #FFF ;
- width: 250px;
- overflow: hidden;
- font-size: 1.2em;
- clear: both;
-}
-
-.toggle_container .block {
- background-color: #DBE4E8;
- padding: 40 15 40 15px; /*--Padding of Container--*/
- border:1px solid #999;
- color: #000;
-}
-
-.history_table {
- text-align: center;
- background-color: #9999CC;
-}
-
-.history_table2 {
- text-align: center;
- background-color: #DBE4E8;
-}
-
-#filter {
- display: none;
- position: absolute;
- top: 0%;
- left: 0%;
- width: 100%;
- height: 100%;
- background-color: #CCA;
- z-index: 10;
- opacity: .5;
- filter: alpha(opacity=50);
-}
-
-#box {
- display: none;
- position: absolute;
- top: 20%;
- left: 30%;
- width: 500px;
- height: 220px;
- padding: 48px;
- margin: 0;
- border: 1px solid #000;
- background-color: #fff;
- z-index: 101;
- overflow: visible;
-}
-
-#boxtitle {
- position: absolute;
- float: center;
- top: 0;
- left: 0;
- width: 593px;
- height: 20px;
- padding: 0;
- padding-top: 4px;
- left-padding: 8px;
- margin: 0;
- border-bottom: 4px solid #3CF;
- background-color: #D0DCE0;
- color: black;
- font-weight: bold;
- padding-left: 2px;
- text-align: left;
-}
-
-#tblfooter {
- background-color: #D3DCE3;
- float: right;
- padding-top: 10px;
- color: black;
- font-weight: normal;
-}
-
-#foreignkeychk {
- align:left;
- position:absolute;
- cursor:pointer;
-}
-
input.btn {
color: #333;
background-color: #D0DCE0;
diff --git a/themes/original/css/theme_left.css.php b/themes/original/css/navigation.css.php
similarity index 64%
rename from themes/original/css/theme_left.css.php
rename to themes/original/css/navigation.css.php
index 4a593e2cb1..4d04df07d4 100644
--- a/themes/original/css/theme_left.css.php
+++ b/themes/original/css/navigation.css.php
@@ -1,67 +1,41 @@
+
/******************************************************************************/
-/* general tags */
-html {
- font-size: get('fontsize') ? $GLOBALS['PMA_Config']->get('fontsize') : $_COOKIE['pma_fontsize']); ?>;
-}
+/* Navigation */
-input, select, textarea {
- font-size: 1em;
-}
-
-body {
-
- font-family: ;
-
+body#body_leftFrame {
background: ;
color: ;
margin: 0;
- padding: 0.2em 0.2em 0.2em 0.2em;
+ padding: 0.2em;
}
-a img {
- border: 0;
+#body_leftFrame ul {
+ margin: 0;
}
-a:link,
-a:visited,
-a:active {
- text-decoration: none;
- color: #0000FF;
+#body_leftFrame form {
+ margin: 0;
+ padding: 0;
+ display: inline;
}
-ul {
- margin:0;
-}
-
-form {
- margin: 0;
- padding: 0;
- display: inline;
-}
-
-select#select_server,
-select#lightm_db {
- width: 100%;
-}
-
-/* buttons in some browsers (eg. Konqueror) are block elements,
- this breaks design */
-button {
- display: inline;
+#body_leftFrame select#select_server,
+#body_leftFrame select#lightm_db {
+ width: 100%;
}
/******************************************************************************/
@@ -70,74 +44,74 @@ button {
/******************************************************************************/
/* specific elements */
-div#pmalogo {
+#body_leftFrame div#pmalogo {
background-color: ;
padding:.3em;
}
-div#recentTableList {
+#body_leftFrame div#recentTableList {
text-align: center;
margin-bottom: 0.5em;
}
-div#recentTableList select {
+#body_leftFrame div#recentTableList select {
width: 100%;
}
-div#pmalogo,
-div#leftframelinks,
-div#databaseList {
+#body_leftFrame div#pmalogo,
+#body_leftFrame div#leftframelinks,
+#body_leftFrame div#databaseList {
text-align: center;
margin-bottom: 0.5em;
padding-bottom: 0.5em;
}
-ul#databaseList {
+#body_leftFrame ul#databaseList {
margin-bottom: 0.5em;
padding-bottom: 0.5em;
padding-: 1.5em;
font-style: italic;
}
-ul#databaseList a {
+#body_leftFrame ul#databaseList a {
display: block;
font-style: normal;
}
-div#navidbpageselector a,
-ul#databaseList a {
+#body_leftFrame div#navidbpageselector a,
+#body_leftFrame ul#databaseList a {
background: ;
color: ;
}
-ul#databaseList ul {
+#body_leftFrame ul#databaseList ul {
padding-left: 1em;
padding-right: 0;
}
-ul#databaseList a:hover {
+#body_leftFrame ul#databaseList a:hover {
background: ;
color: ;
}
-ul#databaseList li.selected a {
+#body_leftFrame ul#databaseList li.selected a {
background: ;
color: ;
}
-div#leftframelinks .icon {
+#body_leftFrame div#leftframelinks .icon {
padding: 0;
margin: 0;
}
-div#leftframelinks a img.icon {
+#body_leftFrame div#leftframelinks a img.icon {
margin: 2px;
border: 0.1em solid ;
padding: 0;
}
-div#leftframelinks a:hover img {
+#body_leftFrame div#leftframelinks a:hover img {
background-color: ;
color: ;
}
@@ -157,7 +131,7 @@ div#leftframelinks a:hover img {
font-size: 80%;
}
-div#left_tableList ul {
+#body_leftFrame div#left_tableList ul {
list-style-type: none;
list-style-position: outside;
margin: 0;
@@ -166,23 +140,23 @@ div#left_tableList ul {
background: ;
}
-div#left_tableList ul ul {
+#body_leftFrame div#left_tableList ul ul {
font-size: 100%;
}
-div#left_tableList a {
+#body_leftFrame div#left_tableList a {
background: ;
color: ;
text-decoration: none;
}
-div#left_tableList a:hover {
+#body_leftFrame div#left_tableList a:hover {
background: ;
color: ;
text-decoration: underline;
}
-div#left_tableList li {
+#body_leftFrame div#left_tableList li {
margin: 0;
padding: 0;
white-space: nowrap;
@@ -190,50 +164,50 @@ div#left_tableList li {
/* marked items */
-div#left_tableList > ul li.marked > a,
-div#left_tableList > ul li.marked {
+#body_leftFrame div#left_tableList > ul li.marked > a,
+#body_leftFrame div#left_tableList > ul li.marked {
background: ;
color: ;
}
-div#left_tableList > ul li:hover > a,
-div#left_tableList > ul li:hover {
+#body_leftFrame div#left_tableList > ul li:hover > a,
+#body_leftFrame div#left_tableList > ul li:hover {
background: ;
color: ;
}
-div#left_tableList img {
- padding: 0;
- vertical-align: middle;
+#body_leftFrame div#left_tableList img {
+ padding: 0;
+ vertical-align: middle;
}
-div#left_tableList ul ul {
- margin-: 0;
- padding-: 0.1em;
- border-: 0.1em solid ;
- padding-bottom: 0.1em;
- border-bottom: 0.1em solid ;
+#body_leftFrame div#left_tableList ul ul {
+ margin-: 0;
+ padding-: .1em;
+ border-: .1em solid ;
+ padding-bottom: .1em;
+ border-bottom: .1em solid ;
}
/* for the servers list in navi panel */
-#serverinfo .item {
+#body_leftFrame #serverinfo .item {
white-space: nowrap;
color: ;
}
-#serverinfo a:hover {
+#body_leftFrame #serverinfo a:hover {
background: ;
color: ;
}
-#NavFilter {
+#body_leftFrame #NavFilter {
display: none;
}
-#clear_fast_filter,
-#clear_fast_db_filter {
+#body_leftFrame #clear_fast_filter,
+#body_leftFrame #clear_fast_db_filter {
background: white;
color: black;
cursor: pointer;
@@ -243,16 +217,15 @@ div#left_tableList ul ul {
float: right;
}
-#fast_filter,
-#fast_db_filter {
+#body_leftFrame #fast_filter,
+#body_leftFrame #fast_db_filter {
width: 100%;
padding: 2px 0;
margin: 0;
border: 0;
}
-#fast_filter.gray,
-#fast_db_fiter.gray {
+#body_leftFrame #fast_filter.gray,
+#body_leftFrame #fast_db_fiter.gray {
color: gray;
}
-
diff --git a/themes/pmahomme/css/theme_right.css.php b/themes/pmahomme/css/common.css.php
similarity index 80%
rename from themes/pmahomme/css/theme_right.css.php
rename to themes/pmahomme/css/common.css.php
index feb9c2231b..c3454d9a52 100644
--- a/themes/pmahomme/css/theme_right.css.php
+++ b/themes/pmahomme/css/common.css.php
@@ -1,14 +1,14 @@
@@ -2102,44 +2102,6 @@ input#input_import_file {
margin: 5px 0 5px 0;
}
-/**
- * GIS data editor styles
- */
-a.close_gis_editor {
- float: right;
-}
-
-#gis_editor {
- display: none;
- position: fixed;
- _position: absolute; /* hack for IE */
- z-index: 1001;
- overflow-y: auto;
- overflow-x: hidden;
-}
-
-#gis_data {
- min-height: 230px;
-}
-
-#gis_data_textarea {
- height: 6em;
-}
-
-#gis_data_editor {
- background: #D0DCE0;
- padding: 15px;
- min-height: 500px;
-}
-
-#gis_data_editor .choice {
- display: none;
-}
-
-#gis_data_editor input[type="text"] {
- width: 75px;
-}
-
#popup_background {
display: none;
position: fixed;
@@ -2153,89 +2115,6 @@ a.close_gis_editor {
overflow: hidden;
}
-/**
- * ENUM/SET editor styles
- */
-p.enum_notice {
- margin: 5px 2px;
- font-size: 80%;
-}
-
-.enum_editor_no_js fieldset {
- width: 40em;
-}
-
-hr.enum_editor_no_js {
- background-color: #aaa;
-}
-
-#enum_editor p {
- margin-top: 0;
- font-style: italic;
-}
-
-#enum_editor .values,
-#enum_editor .add,
-.enum_editor_no_js #values {
- width: 100%;
-}
-
-#enum_editor .add td {
- vertical-align: middle;
- width: 50%;
- padding: 0 0 0 1em;
-}
-
-#enum_editor .values td.drop {
- width: 1.8em;
- cursor: pointer;
- vertical-align: middle;
-}
-
-#enum_editor .values input {
- margin: .1em 0;
- padding-right: 2em;
- width: 100%;
-}
-
-#enum_editor .values img {
- width: 1.8em;
- vertical-align: middle;
-}
-
-#enum_editor input.add_value {
- margin: 0 .4em 0 0;
-}
-
-#enum_editor_output textarea,
-.enum_editor_no_js input {
- width: 100%;
- float: right;
- margin: 1em 0 0 0;
-}
-
-.enum_editor_no_js {
- width: 40em;
-}
-
-.enum_editor_no_js input.submit {
- float: left;
- margin: 1em 0;
-}
-
-/**
- * ENUM/SET editor integration for the routines editor
- */
-.enum_hint {
- position: relative;
-}
-
-.enum_hint a {
- position: absolute;
- left: 81%;
- bottom: .35em;
-}
-
/**
* Table structure styles
*/
@@ -2580,34 +2459,6 @@ fieldset .disabled-field td {
margin-bottom: .5em;
}
-.rte_table {
- table-layout: fixed;
-}
-
-.rte_table td {
- vertical-align: middle;
- padding: 0.2em;
-}
-
-.rte_table tr td:nth-child(1) {
- font-weight: bold;
-}
-
-.rte_table input,
-.rte_table select,
-.rte_table textarea {
- width: 100%;
- margin: 0;
- box-sizing: border-box;
- -ms-box-sizing: border-box;
- -moz-box-sizing: border-box;
- -webkit-box-sizing: border-box;
-}
-
-.rte_table .routine_params_table {
- width: 100%;
-}
-
#placeholder .button {
position: absolute;
cursor: pointer;
@@ -2737,30 +2588,6 @@ fieldset .disabled-field td {
top: 103px;
}
-.gis_table td {
- vertical-align: middle;
-}
-
-.gis_table select {
- min-width: 160px;
- margin: 6px;
-}
-
-.gis_table .save {
- color: #111;
- font-weight: bold;
- vertical-align: bottom;
- height: 100px;
-}
-
-.gis_table .button {
- text-align: ;
-}
-
-.gis_table .choice {
- display: none;
-}
-
getCssCodeMirror(true); ?>
.colborder {
@@ -3031,515 +2858,6 @@ fieldset .disabled-field td {
.ui-timepicker-div dl dd { margin: -25px 0 10px 65px; }
.ui-timepicker-div td { font-size: 90%; }
-/* Designer */
-.input_tab {
- background-color: #A6C7E1;
- color: #000;
-}
-
-#canvas {
- background-color: #fff;
- color: #000;
-}
-
-canvas.pmd {
- display: inline-block;
- overflow: hidden;
- text-align: left;
-}
-
-canvas.pmd * {
- behavior: url(#default#VML);
-}
-
-.pmd_tab {
- background-color: #fff;
- color: #000;
- border-collapse: collapse;
- border: 1px solid #aaa;
- z-index: 1;
- -moz-user-select: none;
-}
-
-.tab_zag {
- background-image: url(getImgPath(); ?>pmd/Header.png);
- background-repeat: repeat-x;
- text-align: center;
- cursor: move;
- padding: 1px;
- font-weight: bold;
-}
-
-.tab_zag_2 {
- background-image: url(getImgPath(); ?>pmd/Header_Linked.png);
- background-repeat: repeat-x;
- text-align: center;
- cursor: move;
- padding: 1px;
- font-weight: bold;
-}
-
-.tab_field {
- background: #fff;
- color: #000;
- cursor: default;
-}
-
-.tab_field_2 {
- background-color: #CCFFCC;
- color: #000;
- background-repeat: repeat-x;
- cursor: default;
-}
-
-.tab_field_3 {
- background-color: #FFE6E6; /*#DDEEFF*/
- color: #000;
- cursor: default;
-}
-
-#pmd_hint {
- white-space: nowrap;
- position: absolute;
- background-color: #99FF99;
- color: #000;
- left: 200px;
- top: 50px;
- z-index: 3;
- border: #00CC66 solid 1px;
- display: none;
-}
-
-.scroll_tab {
- overflow: auto;
- width: 100%;
- height: 500px;
-}
-
-.pmd_Tabs {
- cursor: default;
- color: #0055bb;
- white-space: nowrap;
- text-decoration: none;
- text-indent: 3px;
- font-weight: bold;
- margin-left: 2px;
- text-align: left;
- background-color: #fff;
- background-image: url(getImgPath(); ?>pmd/left_panel_butt.png);
- border: #ccc solid 1px;
-}
-
-.pmd_Tabs2 {
- cursor: default;
- color: #0055bb;
- background: #FFEE99;
- text-indent: 3px;
- font-weight: bold;
- white-space: nowrap;
- text-decoration: none;
- border: #9999FF solid 1px;
- text-align: left;
-}
-
-.owner {
- font-weight: normal;
- color: #888;
-}
-
-.option_tab {
- padding-left: 2px;
- padding-right: 2px;
- width: 5px;
-}
-
-.select_all {
- vertical-align: top;
- padding-left: 2px;
- padding-right: 2px;
- cursor: default;
- width: 1px;
- color: #000;
- background-image: url(getImgPath(); ?>pmd/Header.png);
- background-repeat: repeat-x;
-}
-
-.small_tab {
- vertical-align: top;
- background-color: #0064ea;
- color: #fff;
- background-image: url(getImgPath(); ?>pmd/small_tab.png);
- cursor: default;
- text-align: center;
- font-weight: bold;
- padding-left: 2px;
- padding-right: 2px;
- width: 1px;
- text-decoration: none;
-}
-
-.small_tab2 {
- vertical-align: top;
- color: #fff;
- background-color: #FF9966;
- cursor: default;
- padding-left: 2px;
- padding-right: 2px;
- text-align: center;
- font-weight: bold;
- width: 1px;
- text-decoration: none;
-}
-
-.small_tab_pref {
- background-image: url(getImgPath(); ?>pmd/Header.png);
- background-repeat: repeat-x;
- text-align: center;
- width: 1px;
-}
-
-.small_tab_pref2 {
- vertical-align: top;
- color: #fff;
- background-color: #FF9966;
- cursor: default;
- text-align: center;
- font-weight: bold;
- width: 1px;
- text-decoration: none;
-}
-
-.butt {
- border: #4477aa solid 1px;
- font-weight: bold;
- height: 19px;
- width: 70px;
- background-color: #fff;
- color: #000;
- vertical-align: baseline;
-}
-
-.L_butt2_1 {
- padding: 1px;
- text-decoration: none;
- background-color: #fff;
- color: #000;
- vertical-align: middle;
- cursor: default;
-}
-
-.L_butt2_2 {
- padding: 0;
- border: #0099CC solid 1px;
- background: #FFEE99;
- text-decoration: none;
- color: #000;
- cursor: default;
-}
-
-/* ---------------------------------------------------------------------------*/
-.bor {
- width: 10px;
- height: 10px;
-}
-
-.frams1 {
- background: url(getImgPath(); ?>pmd/1.png) no-repeat right bottom;
-}
-
-.frams2 {
- background: url(getImgPath(); ?>pmd/2.png) no-repeat left bottom;
-}
-
-.frams3 {
- background: url(getImgPath(); ?>pmd/3.png) no-repeat left top;
-}
-
-.frams4 {
- background: url(getImgPath(); ?>pmd/4.png) no-repeat right top;
-}
-
-.frams5 {
- background: url(getImgPath(); ?>pmd/5.png) repeat-x center bottom;
-}
-
-.frams6 {
- background: url(getImgPath(); ?>pmd/6.png) repeat-y left;
-}
-
-.frams7 {
- background: url(getImgPath(); ?>pmd/7.png) repeat-x top;
-}
-
-.frams8 {
- background: url(getImgPath(); ?>pmd/8.png) repeat-y right;
-}
-
-#osn_tab {
- background-color: #fff;
- color: #000;
- border: #A9A9A9 solid 1px;
-}
-
-.pmd_header {
- background-color: #EAEEF0;
- color: #000;
- text-align: center;
- font-weight: bold;
- margin: 0;
- padding: 0;
- background-image: url(getImgPath(); ?>pmd/top_panel.png);
- background-position: top;
- background-repeat: repeat-x;
- border-right: #999 solid 1px;
- border-left: #999 solid 1px;
- height: 28px;
-}
-
-.pmd_header a {
- display: block;
- float: left;
- margin: 3px 1px 4px 1px;
- height: 20px;
- border: 1px dotted #fff;
-}
-
-.pmd_header .M_bord {
- display: block;
- float: left;
- margin: 4px;
- height: 20px;
- width: 2px;
-}
-
-.pmd_header a.first {
- margin-right: 1em;
-}
-
-.pmd_header a.last {
- margin-left: 1em;
-}
-
-a.M_butt_Selected_down_IE,
-a.M_butt_Selected_down {
- border: 1px solid #C0C0BB;
- background-color: #99FF99;
- color: #000;
-}
-
-a.M_butt_Selected_down_IE:hover,
-a.M_butt_Selected_down:hover,
-a.M_butt:hover {
- border: 1px solid #0099CC;
- background-color: #FFEE99;
- color: #000;
-}
-
-#layer_menu {
- z-index: 1000;
- position: absolute;
- left: 0;
- background-color: #EAEEF0;
- border: #999 solid 1px;
-}
-
-#layer_upd_relation {
- position: absolute;
- left: 637px;
- top: 224px;
- z-index: 1000;
-}
-
-#layer_new_relation {
- position: absolute;
- left: 636px;
- top: 85px;
- z-index: 1000;
- width: 153px;
-}
-
-#pmd_optionse {
- position: absolute;
- left: 636px;
- top: 85px;
- z-index: 1000;
- width: 153px;
-}
-
-#layer_menu_sizer {
- background-image: url(getImgPath(); ?>pmd/resize.png);
- cursor: nw-resize;
- width: 16px;
- height: 16px;
-}
-
-.panel {
- position: fixed;
- top: 50px;
- right: 0;
- display: none;
- background: #FFF;
- border: 1px solid #F5F5F5;
- width: 350 px;
- height: auto;
- padding: 30px 170px 30px 30px;
- color: #FFF;
- z-index: 99;
-}
-
-a.trigger {
- position: fixed;
- text-decoration: none;
- top: 60px; right: 0;
- color: #fff;
- padding: 10px 40px 10px 15px;
- background: #333 url(getImgPath(); ?>pmd/plus.png) 85% 55% no-repeat;
- border: 1px solid #444;
- display: block;
-}
-
-a.trigger:hover {
- position: fixed;
- text-decoration: none;
- top: 60px; right: 0;
- color: #080808;
- padding: 10px 40px 10px 15px;
- background: #fff696 url(getImgPath(); ?>pmd/plus.png) 85% 55% no-repeat;
- border: 1px solid #999;
- display: block;
-}
-
-a.active.trigger {
- background: #222 url(getImgPath(); ?>pmd/minus.png) 85% 55% no-repeat;
- z-index: 999;
-}
-
-a.active.trigger:hover {
- background: #fff696 url(getImgPath(); ?>pmd/minus.png) 85% 55% no-repeat;
- z-index: 999;
-}
-
-h2.tiger {
- background-repeat: repeat-x;
- padding: 1px;
- font-weight: bold;
- padding: 50 20 50 20px;
- margin: 0 0 5px 0;
- width: 250px;
- float: left;
- color : #333;
- text-align: center;
-}
-
-h2.tiger a {
- background-image: url(getImgPath(); ?>pmd/Header.png);
- text-align: center;
- text-decoration: none;
- color : #333;
- display: block;
-}
-
-h2.tiger a:hover {
- color: #000;
- background-image: url(getImgPath(); ?>pmd/Header_Linked.png);
-}
-
-h2.active {
- background-image: url(getImgPath(); ?>pmd/Header.png);
- background-repeat: repeat-x;
- padding: 1px;
- background-position: left bottom;
-}
-
-.toggle_container {
- margin: 0 0 5px;
- padding: 0;
- border-top: 1px solid #d6d6d6;
- background: #FFF ;
- width: 250px;
- overflow: hidden;
- font-size: 1.2em;
- clear: both;
-}
-
-.toggle_container .block {
- background-color: #DBE4E8;
- padding: 40 15 40 15px; /*--Padding of Container--*/
- border:1px solid #999;
- color: #000;
-}
-
-.history_table {
- text-align: center;
- background-color: #9999CC;
-}
-
-.history_table2 {
- text-align: center;
- background-color: #DBE4E8;
-}
-
-#filter {
- display: none;
- position: absolute;
- top: 0%;
- left: 0%;
- width: 100%;
- height: 100%;
- background-color: #CCA;
- z-index: 10;
- opacity: .5;
- filter: alpha(opacity=50);
-}
-
-#box {
- display: none;
- position: absolute;
- top: 20%;
- left: 30%;
- width: 500px;
- height: 220px;
- padding: 48px;
- margin: 0;
- border: 1px solid #000;
- background-color: #fff;
- z-index: 101;
- overflow: visible;
-}
-
-#boxtitle {
- position: absolute;
- float: center;
- top: 0;
- left: 0;
- width: 593px;
- height: 20px;
- padding: 0;
- padding-top: 4px;
- left-padding: 8px;
- margin: 0;
- border-bottom: 4px solid #3CF;
- background-color: #D0DCE0;
- color: black;
- font-weight: bold;
- padding-left: 2px;
- text-align: left;
-}
-
-#tblfooter {
- background-color: #D3DCE3;
- float: right;
- padding-top: 10px;
- color: black;
- font-weight: normal;
-}
-
-#foreignkeychk {
- align:left;
- position:absolute;
- cursor:pointer;
-}
-
input.btn {
color: #333;
background-color: #D0DCE0;
@@ -3552,3 +2870,4 @@ body .ui-widget {
.ui-dialog fieldset legend a {
color: #235A81;
}
+
diff --git a/themes/pmahomme/css/enum_editor.css.php b/themes/pmahomme/css/enum_editor.css.php
new file mode 100644
index 0000000000..2318ee58d6
--- /dev/null
+++ b/themes/pmahomme/css/enum_editor.css.php
@@ -0,0 +1,78 @@
+
+
+/**
+ * ENUM/SET editor styles
+ */
+p.enum_notice {
+ margin: 5px 2px;
+ font-size: 80%;
+}
+
+#enum_editor p {
+ margin-top: 0;
+ font-style: italic;
+}
+
+#enum_editor .values,
+#enum_editor .add {
+ width: 100%;
+}
+
+#enum_editor .add td {
+ vertical-align: middle;
+ width: 50%;
+ padding: 0 0 0 1em;
+}
+
+#enum_editor .values td.drop {
+ width: 1.8em;
+ cursor: pointer;
+ vertical-align: middle;
+}
+
+#enum_editor .values input {
+ margin: .1em 0;
+ padding-right: 2em;
+ width: 100%;
+}
+
+#enum_editor .values img {
+ width: 1.8em;
+ vertical-align: middle;
+}
+
+#enum_editor input.add_value {
+ margin: 0 .4em 0 0;
+}
+
+#enum_editor_output textarea {
+ width: 100%;
+ float: right;
+ margin: 1em 0 0 0;
+}
+
+/**
+ * ENUM/SET editor integration for the routines editor
+ */
+.enum_hint {
+ position: relative;
+}
+
+.enum_hint a {
+ position: absolute;
+ left: 81%;
+ bottom: .35em;
+}
diff --git a/themes/pmahomme/css/gis.css.php b/themes/pmahomme/css/gis.css.php
new file mode 100644
index 0000000000..b741e91a94
--- /dev/null
+++ b/themes/pmahomme/css/gis.css.php
@@ -0,0 +1,76 @@
+
+
+.gis_table td {
+ vertical-align: middle;
+}
+
+.gis_table select {
+ min-width: 151px;
+ margin: 6px;
+}
+
+.gis_table .save {
+ color: #111;
+ font-weight: bold;
+ vertical-align: bottom;
+ height: 100px;
+}
+
+.gis_table .button {
+ text-align: ;
+}
+
+.gis_table .choice {
+ display: none;
+}
+
+/**
+ * GIS data editor styles
+ */
+a.close_gis_editor {
+ float: ;
+}
+
+#gis_editor {
+ display: none;
+ position: fixed;
+ _position: absolute; /* hack for IE */
+ z-index: 1001;
+ overflow-y: auto;
+ overflow-x: hidden;
+}
+
+#gis_data {
+ min-height: 230px;
+}
+
+#gis_data_textarea {
+ height: 6em;
+}
+
+#gis_data_editor {
+ background: #D0DCE0;
+ padding: 15px;
+ min-height: 500px;
+}
+
+#gis_data_editor .choice {
+ display: none;
+}
+
+#gis_data_editor input[type="text"] {
+ width: 75px;
+}
diff --git a/themes/pmahomme/css/theme_left.css.php b/themes/pmahomme/css/navigation.css.php
similarity index 65%
rename from themes/pmahomme/css/theme_left.css.php
rename to themes/pmahomme/css/navigation.css.php
index 92f64b0c9a..be681bf8ef 100644
--- a/themes/pmahomme/css/theme_left.css.php
+++ b/themes/pmahomme/css/navigation.css.php
@@ -1,31 +1,22 @@
+
/******************************************************************************/
-/* general tags */
-html {
- font-size: get('fontsize') ? $GLOBALS['PMA_Config']->get('fontsize') : $_COOKIE['pma_fontsize']); ?>;
-}
+/* Navigation */
-input, select, textarea {
- font-size: 1em;
-}
-
-body {
-
- font-family: ;
-
+body#body_leftFrame {
background: url(./themes/pmahomme/img/left_nav_bg.png) repeat-y right 0% #f3f3f3;
border-right: 1px solid #aaa;
color: ;
@@ -33,42 +24,25 @@ body {
padding: 0;
}
-a img {
- border: 0;
-}
-
-a:link,
-a:visited,
-a:active {
- text-decoration: none;
- color: #0000FF;
-}
-
-ul {
+#body_leftFrame ul {
margin: 0;
}
-form {
+#body_leftFrame form {
margin: 0;
padding: 0;
display: inline;
}
-select#select_server,
-select#lightm_db {
+#body_leftFrame select#select_server,
+#body_leftFrame select#lightm_db {
width: 100%;
}
-/* buttons in some browsers (eg. Konqueror) are block elements,
- this breaks design */
-button {
- display: inline;
-}
-
/******************************************************************************/
/* classes */
-.navi_dbName {
+#body_leftFrame .navi_dbName {
font-weight: bold;
color: ;
}
@@ -76,38 +50,38 @@ button {
/******************************************************************************/
/* specific elements */
-div#pmalogo {
+#body_leftFrame div#pmalogo {
}
-div#recentTableList {
+#body_leftFrame div#recentTableList {
text-align: center;
margin: 20px 10px 0px 10px;
}
-div#recentTableList select {
+#body_leftFrame div#recentTableList select {
width: 100%;
}
-div#pmalogo,
-div#leftframelinks,
-div#databaseList {
+#body_leftFrame div#pmalogo,
+#body_leftFrame div#leftframelinks,
+#body_leftFrame div#databaseList {
text-align: center;
margin: 5px 10px 0px 10px;
}
-ul#databaseList {
+#body_leftFrame ul#databaseList {
margin: .8em 0px;
padding-bottom: .5em;
padding-: .3em;
font-style: italic;
}
-ul#databaseList span {
+#body_leftFrame ul#databaseList span {
padding: 5px;
}
-ul#databaseList a {
+#body_leftFrame ul#databaseList a {
color: #333;
background: url(./themes/pmahomme/img/database.png) no-repeat 0 5px transparent;
display: block;
@@ -116,51 +90,51 @@ ul#databaseList a {
font-style: normal;
}
-div#navidbpageselector {
+#body_leftFrame div#navidbpageselector {
margin: .1em;
text-align: center;
}
-div#navidbpageselector a,
-div#navidbpageselector select{
+#body_leftFrame div#navidbpageselector a,
+#body_leftFrame div#navidbpageselector select{
color: #333;
margin: .2em;
}
-ul#databaseList ul {
+#body_leftFrame ul#databaseList ul {
margin: 0;
padding: 0;
}
-ul#databaseList li {
+#body_leftFrame ul#databaseList li {
list-style: none;
text-indent: 20px;
margin: 0;
padding: 0;
}
-ul#databaseList a:hover {
+#body_leftFrame ul#databaseList a:hover {
background-color: #e4e4e4;
}
-ul#databaseList li.selected a {
+#body_leftFrame ul#databaseList li.selected a {
background: ;
color: ;
}
-div#leftframelinks .icon {
+#body_leftFrame div#leftframelinks .icon {
padding: 0;
margin: 0;
}
-div#reloadlink a img,
-div#leftframelinks a img.icon {
+#body_leftFrame div#reloadlink a img,
+#body_leftFrame div#leftframelinks a img.icon {
margin: .3em;
margin-top: .7em;
border: 0;
}
-div#leftframelinks a:hover img {
+#body_leftFrame div#leftframelinks a:hover img {
}
@@ -178,40 +152,40 @@ div#leftframelinks a:hover img {
padding: 0;
}
-div#left_tableList {margin:10px 10px 0 10px;}
-div#left_tableList ul {
+#body_leftFrame div#left_tableList {margin:10px 10px 0 10px;}
+#body_leftFrame div#left_tableList ul {
list-style-type: none;
list-style-position: outside;
margin: 0;
padding: 0;
}
-div#left_tableList ul ul {
+#body_leftFrame div#left_tableList ul ul {
font-size: 100%;
}
-div#left_tableList a {
+#body_leftFrame div#left_tableList a {
color: ;
text-decoration: none;
}
-div#left_tableList a:hover {
+#body_leftFrame div#left_tableList a:hover {
background: ;
color: ;
text-decoration: underline;
}
-div#left_tableList li {
+#body_leftFrame div#left_tableList li {
margin: 0;
padding: 2px 0;
white-space: nowrap;
}
-#newtable {
+#body_leftFrame #newtable {
margin-top: 15px !important;
}
-#newtable a {
+#body_leftFrame #newtable a {
display: block;
padding: 1px;
getCssGradient('ffffff', 'cccccc'); ?>
@@ -221,50 +195,42 @@ div#left_tableList li {
border-radius: 20px;
}
-#newtable li:hover {
+#body_leftFrame #newtable li:hover {
background: transparent !important;
}
-#newtable a:hover {
+#body_leftFrame #newtable a:hover {
getCssGradient('cccccc', 'dddddd'); ?>
}
-#newtable li a:hover {
+#body_leftFrame #newtable li a:hover {
text-decoration: none;
}
-select{
- -moz-border-radius: 2px 2px 2px 2px;
- -moz-box-shadow: 0 1px 2px #DDDDDD;
- border: 1px solid #aaa;
- color: #333;
- padding: 3px;
- background: white;
-}
/* marked items */
-div#left_tableList > ul li.marked > a,
-div#left_tableList > ul li.marked {
+#body_leftFrame div#left_tableList > ul li.marked > a,
+#body_leftFrame div#left_tableList > ul li.marked {
background: #e4e4e4;
color: ;
}
-div#left_tableList > ul li:hover > a,
-div#left_tableList > ul li:hover {
+#body_leftFrame div#left_tableList > ul li:hover > a,
+#body_leftFrame div#left_tableList > ul li:hover {
background: #e4e4e4;
color: ;
}
-div#left_tableList img {
+#body_leftFrame div#left_tableList img {
padding: 0;
vertical-align: middle;
}
-div#left_tableList ul ul {
+#body_leftFrame div#left_tableList ul ul {
margin-: 0;
padding-: .1em;
border-: .1em solid ;
@@ -273,27 +239,27 @@ div#left_tableList ul ul {
}
/* for the servers list in navi panel */
-#serverinfo .item {
+#body_leftFrame #serverinfo .item {
white-space: nowrap;
color: ;
}
-#serverinfo a:hover {
+#body_leftFrame #serverinfo a:hover {
background: ;
color: ;
}
-#reloadlink {
+#body_leftFrame #reloadlink {
clear: both;
float: ;
display: block;
padding: 1em;
}
-#NavFilter {
+#body_leftFrame #NavFilter {
display: none;
}
-#clear_fast_filter,
-#clear_fast_db_filter {
+#body_leftFrame #clear_fast_filter,
+#body_leftFrame #clear_fast_db_filter {
background: white;
color: black;
cursor: pointer;
@@ -303,13 +269,13 @@ div#left_tableList ul ul {
right: 3ex;
}
-#fast_filter,
-#fast_db_filter {
+#body_leftFrame #fast_filter,
+#body_leftFrame #fast_db_filter {
width: 85%;
padding: .1em;
}
-#fast_filter.gray,
-#fast_db_filter.gray {
+#body_leftFrame #fast_filter.gray,
+#body_leftFrame #fast_db_filter.gray {
color: gray;
}
diff --git a/themes/pmahomme/css/pmd.css.php b/themes/pmahomme/css/pmd.css.php
new file mode 100644
index 0000000000..df192ffe5e
--- /dev/null
+++ b/themes/pmahomme/css/pmd.css.php
@@ -0,0 +1,523 @@
+
+
+/* Designer */
+.input_tab {
+ background-color: #A6C7E1;
+ color: #000;
+}
+
+#canvas {
+ background-color: #fff;
+ color: #000;
+}
+
+canvas.pmd {
+ display: inline-block;
+ overflow: hidden;
+ text-align: left;
+}
+
+canvas.pmd * {
+ behavior: url(#default#VML);
+}
+
+.pmd_tab {
+ background-color: #fff;
+ color: #000;
+ border-collapse: collapse;
+ border: 1px solid #aaa;
+ z-index: 1;
+ -moz-user-select: none;
+}
+
+.tab_zag {
+ background-image: url(getImgPath(); ?>pmd/Header.png);
+ background-repeat: repeat-x;
+ text-align: center;
+ cursor: move;
+ padding: 1px;
+ font-weight: bold;
+}
+
+.tab_zag_2 {
+ background-image: url(getImgPath(); ?>pmd/Header_Linked.png);
+ background-repeat: repeat-x;
+ text-align: center;
+ cursor: move;
+ padding: 1px;
+ font-weight: bold;
+}
+
+.tab_field {
+ background: #fff;
+ color: #000;
+ cursor: default;
+}
+
+.tab_field_2 {
+ background-color: #CCFFCC;
+ color: #000;
+ background-repeat: repeat-x;
+ cursor: default;
+}
+
+.tab_field_3 {
+ background-color: #FFE6E6; /*#DDEEFF*/
+ color: #000;
+ cursor: default;
+}
+
+#pmd_hint {
+ white-space: nowrap;
+ position: absolute;
+ background-color: #99FF99;
+ color: #000;
+ left: 200px;
+ top: 50px;
+ z-index: 3;
+ border: #00CC66 solid 1px;
+ display: none;
+}
+
+.scroll_tab {
+ overflow: auto;
+ width: 100%;
+ height: 500px;
+}
+
+.pmd_Tabs {
+ cursor: default;
+ color: #0055bb;
+ white-space: nowrap;
+ text-decoration: none;
+ text-indent: 3px;
+ font-weight: bold;
+ margin-left: 2px;
+ text-align: left;
+ background-color: #fff;
+ background-image: url(getImgPath(); ?>pmd/left_panel_butt.png);
+ border: #ccc solid 1px;
+}
+
+.pmd_Tabs2 {
+ cursor: default;
+ color: #0055bb;
+ background: #FFEE99;
+ text-indent: 3px;
+ font-weight: bold;
+ white-space: nowrap;
+ text-decoration: none;
+ border: #9999FF solid 1px;
+ text-align: left;
+}
+
+.owner {
+ font-weight: normal;
+ color: #888;
+}
+
+.option_tab {
+ padding-left: 2px;
+ padding-right: 2px;
+ width: 5px;
+}
+
+.select_all {
+ vertical-align: top;
+ padding-left: 2px;
+ padding-right: 2px;
+ cursor: default;
+ width: 1px;
+ color: #000;
+ background-image: url(getImgPath(); ?>pmd/Header.png);
+ background-repeat: repeat-x;
+}
+
+.small_tab {
+ vertical-align: top;
+ background-color: #0064ea;
+ color: #fff;
+ background-image: url(getImgPath(); ?>pmd/small_tab.png);
+ cursor: default;
+ text-align: center;
+ font-weight: bold;
+ padding-left: 2px;
+ padding-right: 2px;
+ width: 1px;
+ text-decoration: none;
+}
+
+.small_tab2 {
+ vertical-align: top;
+ color: #fff;
+ background-color: #FF9966;
+ cursor: default;
+ padding-left: 2px;
+ padding-right: 2px;
+ text-align: center;
+ font-weight: bold;
+ width: 1px;
+ text-decoration: none;
+}
+
+.small_tab_pref {
+ background-image: url(getImgPath(); ?>pmd/Header.png);
+ background-repeat: repeat-x;
+ text-align: center;
+ width: 1px;
+}
+
+.small_tab_pref2 {
+ vertical-align: top;
+ color: #fff;
+ background-color: #FF9966;
+ cursor: default;
+ text-align: center;
+ font-weight: bold;
+ width: 1px;
+ text-decoration: none;
+}
+
+.butt {
+ border: #4477aa solid 1px;
+ font-weight: bold;
+ height: 19px;
+ width: 70px;
+ background-color: #fff;
+ color: #000;
+ vertical-align: baseline;
+}
+
+.L_butt2_1 {
+ padding: 1px;
+ text-decoration: none;
+ background-color: #fff;
+ color: #000;
+ vertical-align: middle;
+ cursor: default;
+}
+
+.L_butt2_2 {
+ padding: 0;
+ border: #0099CC solid 1px;
+ background: #FFEE99;
+ text-decoration: none;
+ color: #000;
+ cursor: default;
+}
+
+/* ---------------------------------------------------------------------------*/
+.bor {
+ width: 10px;
+ height: 10px;
+}
+
+.frams1 {
+ background: url(getImgPath(); ?>pmd/1.png) no-repeat right bottom;
+}
+
+.frams2 {
+ background: url(getImgPath(); ?>pmd/2.png) no-repeat left bottom;
+}
+
+.frams3 {
+ background: url(getImgPath(); ?>pmd/3.png) no-repeat left top;
+}
+
+.frams4 {
+ background: url(getImgPath(); ?>pmd/4.png) no-repeat right top;
+}
+
+.frams5 {
+ background: url(getImgPath(); ?>pmd/5.png) repeat-x center bottom;
+}
+
+.frams6 {
+ background: url(getImgPath(); ?>pmd/6.png) repeat-y left;
+}
+
+.frams7 {
+ background: url(getImgPath(); ?>pmd/7.png) repeat-x top;
+}
+
+.frams8 {
+ background: url(getImgPath(); ?>pmd/8.png) repeat-y right;
+}
+
+#osn_tab {
+ background-color: #fff;
+ color: #000;
+ border: #A9A9A9 solid 1px;
+}
+
+.pmd_header {
+ background-color: #EAEEF0;
+ color: #000;
+ text-align: center;
+ font-weight: bold;
+ margin: 0;
+ padding: 0;
+ background-image: url(getImgPath(); ?>pmd/top_panel.png);
+ background-position: top;
+ background-repeat: repeat-x;
+ border-right: #999 solid 1px;
+ border-left: #999 solid 1px;
+ height: 28px;
+}
+
+.pmd_header a {
+ display: block;
+ float: left;
+ margin: 3px 1px 4px 1px;
+ height: 20px;
+ border: 1px dotted #fff;
+}
+
+.pmd_header .M_bord {
+ display: block;
+ float: left;
+ margin: 4px;
+ height: 20px;
+ width: 2px;
+}
+
+.pmd_header a.first {
+ margin-right: 1em;
+}
+
+.pmd_header a.last {
+ margin-left: 1em;
+}
+
+a.M_butt_Selected_down_IE,
+a.M_butt_Selected_down {
+ border: 1px solid #C0C0BB;
+ background-color: #99FF99;
+ color: #000;
+}
+
+a.M_butt_Selected_down_IE:hover,
+a.M_butt_Selected_down:hover,
+a.M_butt:hover {
+ border: 1px solid #0099CC;
+ background-color: #FFEE99;
+ color: #000;
+}
+
+#layer_menu {
+ z-index: 1000;
+ position: absolute;
+ left: 0;
+ background-color: #EAEEF0;
+ border: #999 solid 1px;
+}
+
+#layer_upd_relation {
+ position: absolute;
+ left: 637px;
+ top: 224px;
+ z-index: 1000;
+}
+
+#layer_new_relation {
+ position: absolute;
+ left: 636px;
+ top: 85px;
+ z-index: 1000;
+ width: 153px;
+}
+
+#pmd_optionse {
+ position: absolute;
+ left: 636px;
+ top: 85px;
+ z-index: 1000;
+ width: 153px;
+}
+
+#layer_menu_sizer {
+ background-image: url(getImgPath(); ?>pmd/resize.png);
+ cursor: nw-resize;
+ width: 16px;
+ height: 16px;
+}
+
+.panel {
+ position: fixed;
+ top: 50px;
+ right: 0;
+ display: none;
+ background: #FFF;
+ border: 1px solid #F5F5F5;
+ width: 350 px;
+ height: auto;
+ padding: 30px 170px 30px 30px;
+ color: #FFF;
+ z-index: 99;
+}
+
+a.trigger {
+ position: fixed;
+ text-decoration: none;
+ top: 60px; right: 0;
+ color: #fff;
+ padding: 10px 40px 10px 15px;
+ background: #333 url(getImgPath(); ?>pmd/plus.png) 85% 55% no-repeat;
+ border: 1px solid #444;
+ display: block;
+}
+
+a.trigger:hover {
+ position: fixed;
+ text-decoration: none;
+ top: 60px; right: 0;
+ color: #080808;
+ padding: 10px 40px 10px 15px;
+ background: #fff696 url(getImgPath(); ?>pmd/plus.png) 85% 55% no-repeat;
+ border: 1px solid #999;
+ display: block;
+}
+
+a.active.trigger {
+ background: #222 url(getImgPath(); ?>pmd/minus.png) 85% 55% no-repeat;
+ z-index: 999;
+}
+
+a.active.trigger:hover {
+ background: #fff696 url(getImgPath(); ?>pmd/minus.png) 85% 55% no-repeat;
+ z-index: 999;
+}
+
+h2.tiger {
+ background-repeat: repeat-x;
+ padding: 1px;
+ font-weight: bold;
+ padding: 50 20 50 20px;
+ margin: 0 0 5px 0;
+ width: 250px;
+ float: left;
+ color : #333;
+ text-align: center;
+}
+
+h2.tiger a {
+ background-image: url(getImgPath(); ?>pmd/Header.png);
+ text-align: center;
+ text-decoration: none;
+ color : #333;
+ display: block;
+}
+
+h2.tiger a:hover {
+ color: #000;
+ background-image: url(getImgPath(); ?>pmd/Header_Linked.png);
+}
+
+h2.active {
+ background-image: url(getImgPath(); ?>pmd/Header.png);
+ background-repeat: repeat-x;
+ padding: 1px;
+ background-position: left bottom;
+}
+
+.toggle_container {
+ margin: 0 0 5px;
+ padding: 0;
+ border-top: 1px solid #d6d6d6;
+ background: #FFF ;
+ width: 250px;
+ overflow: hidden;
+ font-size: 1.2em;
+ clear: both;
+}
+
+.toggle_container .block {
+ background-color: #DBE4E8;
+ padding: 40 15 40 15px; /*--Padding of Container--*/
+ border:1px solid #999;
+ color: #000;
+}
+
+.history_table {
+ text-align: center;
+ background-color: #9999CC;
+}
+
+.history_table2 {
+ text-align: center;
+ background-color: #DBE4E8;
+}
+
+#filter {
+ display: none;
+ position: absolute;
+ top: 0%;
+ left: 0%;
+ width: 100%;
+ height: 100%;
+ background-color: #CCA;
+ z-index: 10;
+ opacity: .5;
+ filter: alpha(opacity=50);
+}
+
+#box {
+ display: none;
+ position: absolute;
+ top: 20%;
+ left: 30%;
+ width: 500px;
+ height: 220px;
+ padding: 48px;
+ margin: 0;
+ border: 1px solid #000;
+ background-color: #fff;
+ z-index: 101;
+ overflow: visible;
+}
+
+#boxtitle {
+ position: absolute;
+ float: center;
+ top: 0;
+ left: 0;
+ width: 593px;
+ height: 20px;
+ padding: 0;
+ padding-top: 4px;
+ left-padding: 8px;
+ margin: 0;
+ border-bottom: 4px solid #3CF;
+ background-color: #D0DCE0;
+ color: black;
+ font-weight: bold;
+ padding-left: 2px;
+ text-align: left;
+}
+
+#tblfooter {
+ background-color: #D3DCE3;
+ float: right;
+ padding-top: 10px;
+ color: black;
+ font-weight: normal;
+}
+
+#foreignkeychk {
+ align:left;
+ position:absolute;
+ cursor:pointer;
+}
diff --git a/themes/pmahomme/css/rte.css.php b/themes/pmahomme/css/rte.css.php
new file mode 100644
index 0000000000..0db21a805c
--- /dev/null
+++ b/themes/pmahomme/css/rte.css.php
@@ -0,0 +1,43 @@
+
+
+.rte_table {
+ table-layout: fixed;
+}
+
+.rte_table td {
+ vertical-align: middle;
+ padding: 0.2em;
+}
+
+.rte_table tr td:nth-child(1) {
+ font-weight: bold;
+}
+
+.rte_table input,
+.rte_table select,
+.rte_table textarea {
+ width: 100%;
+ margin: 0;
+ box-sizing: border-box;
+ -ms-box-sizing: border-box;
+ -moz-box-sizing: border-box;
+ -webkit-box-sizing: border-box;
+}
+
+.rte_table .routine_params_table {
+ width: 100%;
+}
diff --git a/libraries/Theme.class.php b/libraries/Theme.class.php
index 77dbdd2176..4112db98ae 100644
--- a/libraries/Theme.class.php
+++ b/libraries/Theme.class.php
@@ -15,9 +15,6 @@ if (! defined('PHPMYADMIN')) {
* @todo add the possibility to make a theme depend on another theme
* and by default on original
* @todo make all components optional - get missing components from 'parent' theme
- * @todo make css optionally replacing 'parent' css or extending it
- * (by appending at the end)
- * @todo add an optional global css file - which will be used for both frames
*
* @package PhpMyAdmin
*/
@@ -53,12 +50,6 @@ class PMA_Theme
*/
var $img_path = '';
- /**
- * @var array valid css types
- * @access protected
- */
- var $types = array('left', 'right');
-
/**
* @var integer last modification time for info file
* @access protected
@@ -73,10 +64,23 @@ class PMA_Theme
*/
var $filesize_info = 0;
+ /**
+ * @var array List of css files to load
+ * @access private
+ */
+ private $css_files = array(
+ 'common',
+ 'enum_editor',
+ 'gis',
+ 'navigation',
+ 'pmd',
+ 'rte'
+ );
+
/**
* Loads theme information
*
- * @return boolean whether loading them info was successful or not *
+ * @return boolean whether loading them info was successful or not
* @access public
*/
function loadInfo()
@@ -135,7 +139,7 @@ class PMA_Theme
}
/**
* checks image path for existance - if not found use img from original theme
*
* @access public
* @return bool
@@ -145,8 +149,8 @@ class PMA_Theme
if (is_dir($this->getPath() . '/img/')) {
$this->setImgPath($this->getPath() . '/img/');
return true;
- } elseif (is_dir($GLOBALS['cfg']['ThemePath'] . '/original/img/')) {
- $this->setImgPath($GLOBALS['cfg']['ThemePath'] . '/original/img/');
+ } elseif (is_dir($GLOBALS['cfg']['ThemePath'] . '/' . PMA_Theme_Manager::FALLBACK_THEME . '/img/')) {
+ $this->setImgPath($GLOBALS['cfg']['ThemePath'] . '/' . PMA_Theme_Manager::FALLBACK_THEME . '/img/');
return true;
} else {
trigger_error(
@@ -308,27 +312,14 @@ class PMA_Theme
/**
* load css (send to stdout, normally the browser)
*
- * @param string &$type left, right or print
- *
* @return bool
* @access public
*/
- function loadCss(&$type)
+ function loadCss()
{
- if (empty($type) || ! in_array($type, $this->types)) {
- $type = 'left';
- }
+ $success = true;
- if ($type == 'right') {
- echo PMA_SQP_buildCssData();
- }
-
- $_css_file = $this->getPath()
- . '/css/theme_' . $type . '.css.php';
-
- if (! file_exists($_css_file)) {
- return false;
- }
+ echo PMA_SQP_buildCssData();
if ($GLOBALS['text_dir'] === 'ltr') {
$right = 'right';
@@ -338,22 +329,29 @@ class PMA_Theme
$left = 'right';
}
- include $_css_file;
+ foreach ($this->css_files as $file) {
+ $path = $this->getPath() . "/css/$file.css.php";
+ $fallback = PMA_Theme_Manager::FALLBACK_THEME . "/css/$file.css.php";
- if ($type != 'print') {
- $_sprites_data_file = $this->getPath() . '/sprites.lib.php';
- $_sprites_css_file = './themes/sprites.css.php';
- if (file_exists($_sprites_data_file)
- && is_readable($_sprites_data_file)
- && file_exists($_sprites_css_file)
- && is_readable($_sprites_css_file)
- ) {
- include $_sprites_data_file;
- include $_sprites_css_file;
+ if (is_readable($path)) {
+ echo "\n/* FILE: $file.css.php */\n";
+ include $path;
+ } else if (is_readable($fallback)) {
+ echo "\n/* FILE: $file.css.php */\n";
+ include $fallback;
+ } else {
+ $success = false;
}
}
- return true;
+ $_sprites_data_file = $this->getPath() . '/sprites.lib.php';
+ $_sprites_css_file = './themes/sprites.css.php';
+ if (is_readable($_sprites_data_file)) {
+ include $_sprites_data_file;
+ include $_sprites_css_file;
+ }
+
+ return $success;
}
/**
@@ -135,7 +139,7 @@ class PMA_Theme
}
/**
- * checks image path for existance - if not found use img from original theme
+ * checks image path for existance - if not found use img from fallback theme
*
* @access public